@@ -19,7 +19,7 @@ package MongoDB::BulkWrite;
 # ABSTRACT: MongoDB bulk write interface
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use MongoDB::Error;
 use MongoDB::OID;
@@ -120,6 +120,10 @@ sub _build__client {
     return $self->_database->_client;
 }
 
+with $_ for qw(
+  MongoDB::Role::_DeprecationWarner
+);
+
 #pod =method find
 #pod
 #pod     $view = $bulk->find( $query_document );
@@ -244,9 +248,11 @@ sub execute {
 
     $write_concern ||= $self->collection->write_concern;
 
+
     my $op = MongoDB::Op::_BulkWrite->_new(
         db_name                  => $self->_database->name,
         coll_name                => $self->collection->name,
+        full_name                => $self->collection->full_name,
         queue                    => $self->_queue,
         ordered                  => $self->ordered,
         bypassDocumentValidation => $self->bypassDocumentValidation,
@@ -261,11 +267,13 @@ sub execute {
 # Deprecated methods
 #--------------------------------------------------------------------------#
 
-BEGIN {
-    no warnings 'once';
-    *insert = \&insert_one;
-}
+sub insert {
+    my $self = shift;
 
+    $self->_warn_deprecated( 'insert' => [qw/insert_one/] );
+
+    return $self->insert_one(@_);
+}
 
 1;
 
@@ -281,7 +289,7 @@ MongoDB::BulkWrite - MongoDB bulk write interface
 
 =head1 VERSION
 
-version v1.3.4
+version v1.5.0
 
 =head1 SYNOPSIS
 
@@ -442,6 +450,10 @@ David Golden <david@mongodb.com>
 
 =item *
 
+Rassi <rassi@mongodb.com>
+
+=item *
+
 Mike Friedman <friedo@friedo.com>
 
 =item *
@@ -456,7 +468,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
