@@ -19,16 +19,18 @@ package MongoDB::BulkWriteView;
 # ABSTRACT: Bulk write operations against a query document
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
 use MongoDB::Error;
 use MongoDB::_Types qw(
+    Document
     IxHash
     Booleanpm
 );
 use Types::Standard qw(
+    Maybe
     InstanceOf
 );
 use boolean;
@@ -50,12 +52,26 @@ has _bulk => (
     handles  => [qw/_enqueue_write/]
 );
 
+has _collation => (
+    is  => 'ro',
+    isa => Maybe [Document],
+);
+
 has _upsert => (
     is      => 'ro',
     isa     => Booleanpm,
     default => sub { false },
 );
 
+with $_ for qw(
+  MongoDB::Role::_DeprecationWarner
+);
+
+sub collation {
+    my ($self, $collation) = @_;
+    return $self->new( %$self, _collation => $collation );
+}
+
 sub upsert {
     my ($self) = @_;
     unless ( @_ == 1 ) {
@@ -103,6 +119,7 @@ sub _update {
         multi  => $method eq 'update_many' ? true : false,
         upsert => boolean( $self->_upsert ),
         is_replace => $method eq 'replace_one',
+        (defined $self->_collation ? (collation => $self->_collation) : ()),
     };
 
     $self->_enqueue_write( [ update => $update ] );
@@ -112,13 +129,29 @@ sub _update {
 
 sub delete_many {
     my ($self) = @_;
-    $self->_enqueue_write( [ delete => { q => $self->_query, limit => 0 } ] );
+    $self->_enqueue_write(
+        [
+            delete => {
+                q     => $self->_query,
+                limit => 0,
+                ( defined $self->_collation ? ( collation => $self->_collation ) : () ),
+            }
+        ]
+    );
     return;
 }
 
 sub delete_one {
     my ($self) = @_;
-    $self->_enqueue_write( [ delete => { q => $self->_query, limit => 1 } ] );
+    $self->_enqueue_write(
+        [
+            delete => {
+                q     => $self->_query,
+                limit => 1,
+                ( defined $self->_collation ? ( collation => $self->_collation ) : () ),
+            }
+        ]
+    );
     return;
 }
 
@@ -126,13 +159,29 @@ sub delete_one {
 # Deprecated methods
 #--------------------------------------------------------------------------#
 
-BEGIN {
-    no warnings 'once';
-    *update = \&update_many;
-    *remove = \&delete_many;
-    *remove_one = \&delete_one;
+sub update {
+    my $self = shift;
+
+    $self->_warn_deprecated( 'update' => [qw/update_many/] );
+
+    return $self->update_many(@_);
 }
 
+sub remove {
+    my $self = shift;
+
+    $self->_warn_deprecated( 'remove' => [qw/delete_many/] );
+
+    return $self->delete_many(@_);
+}
+
+sub remove_one {
+    my $self = shift;
+
+    $self->_warn_deprecated( 'remove_one' => [qw/delete_one/] );
+
+    return $self->delete_one(@_);
+}
 
 1;
 
@@ -148,7 +197,7 @@ MongoDB::BulkWriteView - Bulk write operations against a query document
 
 =head1 VERSION
 
-version v1.3.4
+version v1.5.0
 
 =head1 SYNOPSIS
 
@@ -160,6 +209,10 @@ version v1.3.4
     # Update all documents matching the selector
     bulk->find( { a => 2 } )->update_many( { '$inc' => { x => 2 } } );
 
+    # Update all documents matching the selector, with respect to a collation
+    bulk->find( { a => { '$gte' => 'F' } )->collation($collation)
+          ->update_many( { '$inc' => { x => 2 } } );
+
     # Update all documents
     bulk->find( {} )->update_many( { '$inc' => { x => 2 } } );
 
@@ -181,6 +234,9 @@ version v1.3.4
     # Remove all documents matching the selector
     bulk->find( { a => 5 } )->delete_many();
 
+    # Remove all documents matching the selector, with respect to a collation
+    bulk->find( { a => { '$gte' => 'F' } )->collation($collation)->delete_many();
+
     # Remove all documents
     bulk->find( {} )->delete_many();
 
@@ -190,13 +246,22 @@ This class provides means to specify write operations constrained by a query
 document.
 
 To instantiate a C<MongoDB::BulkWriteView>, use the L<find|MongoDB::BulkWrite/find>
-method from L<MongoDB::BulkWrite> or the L</upsert> method described below.
+method from L<MongoDB::BulkWrite>.
 
-Except for L</upsert>, all methods have an empty return on success; an
-exception will be thrown on error.
+Except for L</collation> and L</upsert>, all methods have an empty return on
+success; an exception will be thrown on error.
 
 =head1 METHODS
 
+=head2 collation
+
+    $bulk->collation( $collation )->delete_one;
+
+Returns a new C<MongoDB::BulkWriteView> object, where the specified
+collation will be used to determine which documents match the query
+document.  A collation can be specified for any deletion, replacement,
+or update.
+
 =head2 delete_many
 
     $bulk->delete_many;
@@ -247,6 +312,10 @@ David Golden <david@mongodb.com>
 
 =item *
 
+Rassi <rassi@mongodb.com>
+
+=item *
+
 Mike Friedman <friedo@friedo.com>
 
 =item *
@@ -261,7 +330,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
