@@ -20,15 +20,16 @@ package MongoDB::Database;
 # ABSTRACT: A MongoDB Database
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use MongoDB::CommandResult;
 use MongoDB::Error;
 use MongoDB::GridFS;
 use MongoDB::GridFSBucket;
+use MongoDB::Op::_Command;
+use MongoDB::Op::_DropDatabase;
 use MongoDB::Op::_ListCollections;
 use MongoDB::ReadPreference;
-use MongoDB::_Query;
 use MongoDB::_Types qw(
     BSONCodec
     NonNegNum
@@ -144,6 +145,10 @@ has bson_codec => (
     required => 1,
 );
 
+with $_ for qw(
+  MongoDB::Role::_DeprecationWarner
+);
+
 #--------------------------------------------------------------------------#
 # methods
 #--------------------------------------------------------------------------#
@@ -201,33 +206,41 @@ sub list_collections {
         options    => $options,
     );
 
-    return $self->_client->send_read_op($op);
+    return $self->_client->send_primary_op($op);
 }
 
 #pod =method collection_names
 #pod
 #pod     my @collections = $database->collection_names;
+#pod     my @collections = $database->collection_names( $filter );
 #pod
 #pod Returns the list of collections in this database.
 #pod
-#pod B<Warning:> if the number of collections is very large, this will return
-#pod a very large result.  Use L</list_collections> to iterate over collections
-#pod instead.
+#pod An optional filter document may be provided, which cause only collection
+#pod description documents matching a filter expression to be returned.  See the
+#pod L<listCollections command
+#pod documentation|http://docs.mongodb.org/manual/reference/command/listCollections/>
+#pod for more details on filtering for specific collections.
+#pod
+#pod B<Warning:> if the number of collections is very large, this may return
+#pod a very large result.  Either pass an appropriate filter, or use
+#pod L</list_collections> to iterate over collections instead.
 #pod
 #pod =cut
 
 sub collection_names {
-    my ($self) = @_;
+    my ( $self, $filter ) = @_;
+    $filter ||= {};
 
     my $op = MongoDB::Op::_ListCollections->_new(
         db_name    => $self->name,
         client     => $self->_client,
         bson_codec => $self->bson_codec,
-        filter     => {},
+        filter     => $filter,
         options    => {},
     );
 
-    my $res = $self->_client->send_read_op($op);
+    my $res = $self->_client->send_primary_op($op);
 
     return map { $_->{name} } $res->all;
 }
@@ -325,6 +338,8 @@ sub get_gridfs {
     my ($self, $prefix, $options) = @_;
     $prefix = "fs" unless $prefix;
 
+    $self->_warn_deprecated( 'get_gridfs' => [qw/get_gridfsbucket gfs/] );
+
     return MongoDB::GridFS->new(
         read_preference => $self->read_preference,
         write_concern   => $self->write_concern,
@@ -347,7 +362,13 @@ sub get_gridfs {
 
 sub drop {
     my ($self) = @_;
-    return $self->run_command({ 'dropDatabase' => 1 });
+    return $self->_client->send_write_op(
+        MongoDB::Op::_DropDatabase->_new(
+            db_name       => $self->name,
+            bson_codec    => $self->bson_codec,
+            write_concern => $self->write_concern,
+        )
+    )->output;
 }
 
 #pod =method run_command
@@ -411,6 +432,8 @@ sub run_command {
 sub eval {
     my ($self, $code, $args, $nolock) = @_;
 
+    $self->_warn_deprecated( 'eval', "Run manually via run_command instead." );
+
     $nolock = boolean::false unless defined $nolock;
 
     my $cmd = tie(my %hash, 'Tie::IxHash');
@@ -429,6 +452,10 @@ sub eval {
 
 sub last_error {
     my ( $self, $opt ) = @_;
+
+    $self->_warn_deprecated(
+        'last_error' => "Use a write concern or manually run getlasterror with run_command." );
+
     return $self->run_command( [ getlasterror => 1, ( $opt ? %$opt : () ) ] );
 }
 
@@ -447,7 +474,7 @@ MongoDB::Database - A MongoDB Database
 
 =head1 VERSION
 
-version v1.3.4
+version v1.5.0
 
 =head1 SYNOPSIS
 
@@ -581,12 +608,19 @@ C<maxTimeMS> – the maximum amount of time in milliseconds to allow the command
 =head2 collection_names
 
     my @collections = $database->collection_names;
+    my @collections = $database->collection_names( $filter );
 
 Returns the list of collections in this database.
 
-B<Warning:> if the number of collections is very large, this will return
-a very large result.  Use L</list_collections> to iterate over collections
-instead.
+An optional filter document may be provided, which cause only collection
+description documents matching a filter expression to be returned.  See the
+L<listCollections command
+documentation|http://docs.mongodb.org/manual/reference/command/listCollections/>
+for more details on filtering for specific collections.
+
+B<Warning:> if the number of collections is very large, this may return
+a very large result.  Either pass an appropriate filter, or use
+L</list_collections> to iterate over collections instead.
 
 =head2 get_collection, coll
 
@@ -700,6 +734,10 @@ David Golden <david@mongodb.com>
 
 =item *
 
+Rassi <rassi@mongodb.com>
+
+=item *
+
 Mike Friedman <friedo@friedo.com>
 
 =item *
@@ -714,7 +752,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
