@@ -18,7 +18,7 @@ package MongoDB::GridFSBucket;
 # ABSTRACT: A file storage abstraction
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 use MongoDB::GridFSBucket::DownloadStream;
@@ -368,6 +368,49 @@ sub open_upload_stream {
     );
 }
 
+#pod =method open_upload_stream_with_id
+#pod
+#pod     $stream = $bucket->open_upload_stream_with_id($id, $filename);
+#pod     $stream = $bucket->open_upload_stream_with_id($id, $filename, $options);
+#pod
+#pod     $stream->print('data');
+#pod     $stream->close;
+#pod
+#pod Returns a new L<MongoDB::GridFSBucket::UploadStream> that can be used to
+#pod upload a new file to a GridFS bucket.
+#pod
+#pod This method uses C<$id> as the _id of the file being created, which must be
+#pod unique.
+#pod
+#pod This method requires a filename to store in the C<filename> field of the
+#pod file document.  B<Note>: the filename is an arbitrary string; the method
+#pod does not read from this filename locally.
+#pod
+#pod You can provide an optional hash reference of options, just like
+#pod L</open_upload_stream>.
+#pod
+#pod =cut
+
+sub open_upload_stream_with_id {
+    my ( $self, $id, $filename, $options ) = @_;
+    MongoDB::UsageError->throw('No id provided to open_upload_stream_with_id')
+      unless defined $id && length $id;
+    MongoDB::UsageError->throw('No filename provided to open_upload_stream_with_id')
+      unless defined $filename && length $filename;
+
+    $self->_create_indexes unless $self->_tried_indexing;
+
+    return MongoDB::GridFSBucket::UploadStream->new(
+        {
+            chunk_size_bytes => $self->chunk_size_bytes,
+            ( $options ? %$options : () ),
+            _bucket  => $self,
+            filename => "$filename", # stringify path objects
+            id => $id,
+        }
+    );
+}
+
 #pod =method download_to_stream
 #pod
 #pod     $bucket->download_to_stream($id, $out_fh);
@@ -434,6 +477,49 @@ sub upload_from_stream {
     return $upload_stream->id;
 }
 
+#pod =method upload_from_stream_with_id
+#pod
+#pod     $bucket->upload_from_stream_with_id($id, $filename, $in_fh);
+#pod     $bucket->upload_from_stream_with_id($id, $filename, $in_fh, $options);
+#pod
+#pod Reads from a filehandle and uploads its contents to GridFS.
+#pod
+#pod This method uses C<$id> as the _id of the file being created, which must be
+#pod unique.
+#pod
+#pod This method requires a filename to store in the C<filename> field of the
+#pod file document.  B<Note>: the filename is an arbitrary string; the method
+#pod does not read from this filename locally.
+#pod
+#pod You can provide an optional hash reference of options, just like
+#pod L</open_upload_stream>.
+#pod
+#pod Unlike L</open_upload_stream>, this method returns nothing.
+#pod
+#pod =cut
+
+sub upload_from_stream_with_id {
+    my ( $self, $id, $filename, $source_fh, $options ) = @_;
+    MongoDB::UsageError->throw('No id provided to upload_from_stream_with_id')
+      unless defined $id && length $id;
+    MongoDB::UsageError->throw('No filename provided to upload_from_stream_with_id')
+      unless defined $filename && length $filename;
+    MongoDB::UsageError->throw('No handle provided to upload_from_stream_with_id')
+      unless defined $source_fh;
+    MongoDB::UsageError->throw(
+        'Invalid handle $source_fh provided to upload_from_stream_with_id')
+      unless reftype $source_fh eq 'GLOB';
+
+    my $upload_stream = $self->open_upload_stream_with_id( $id, $filename, $options );
+    my $csb = $upload_stream->chunk_size_bytes;
+    my $buffer;
+    while ( read $source_fh, $buffer, $csb ) {
+        $upload_stream->print($buffer);
+    }
+    $upload_stream->close;
+    return;
+}
+
 #pod =method delete
 #pod
 #pod     $bucket->delete($id);
@@ -485,7 +571,7 @@ MongoDB::GridFSBucket - A file storage abstraction
 
 =head1 VERSION
 
-version v1.3.4
+version v1.5.0
 
 =head1 SYNOPSIS
 
@@ -527,7 +613,7 @@ Valid file documents typically include the following fields:
 
 =item *
 
-_id – a unique ID for this document, typically type BSON ObjectId. Legacy GridFS documents may store this value as a different type. New files must be stored using an ObjectId.
+_id – a unique ID for this document, typically type BSON ObjectId.
 
 =item *
 
@@ -726,6 +812,27 @@ C<metadata> – a hash reference for storing arbitrary metadata about the file.
 
 =back
 
+=head2 open_upload_stream_with_id
+
+    $stream = $bucket->open_upload_stream_with_id($id, $filename);
+    $stream = $bucket->open_upload_stream_with_id($id, $filename, $options);
+
+    $stream->print('data');
+    $stream->close;
+
+Returns a new L<MongoDB::GridFSBucket::UploadStream> that can be used to
+upload a new file to a GridFS bucket.
+
+This method uses C<$id> as the _id of the file being created, which must be
+unique.
+
+This method requires a filename to store in the C<filename> field of the
+file document.  B<Note>: the filename is an arbitrary string; the method
+does not read from this filename locally.
+
+You can provide an optional hash reference of options, just like
+L</open_upload_stream>.
+
 =head2 download_to_stream
 
     $bucket->download_to_stream($id, $out_fh);
@@ -748,6 +855,25 @@ does not read from this filename locally.
 You can provide an optional hash reference of options, just like
 L</open_upload_stream>.
 
+=head2 upload_from_stream_with_id
+
+    $bucket->upload_from_stream_with_id($id, $filename, $in_fh);
+    $bucket->upload_from_stream_with_id($id, $filename, $in_fh, $options);
+
+Reads from a filehandle and uploads its contents to GridFS.
+
+This method uses C<$id> as the _id of the file being created, which must be
+unique.
+
+This method requires a filename to store in the C<filename> field of the
+file document.  B<Note>: the filename is an arbitrary string; the method
+does not read from this filename locally.
+
+You can provide an optional hash reference of options, just like
+L</open_upload_stream>.
+
+Unlike L</open_upload_stream>, this method returns nothing.
+
 =head2 delete
 
     $bucket->delete($id);
@@ -775,6 +901,10 @@ David Golden <david@mongodb.com>
 
 =item *
 
+Rassi <rassi@mongodb.com>
+
+=item *
+
 Mike Friedman <friedo@friedo.com>
 
 =item *
@@ -789,7 +919,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
