@@ -18,7 +18,7 @@ package MongoDB::GridFSBucket::UploadStream;
 # ABSTRACT: File handle abstraction for uploading
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 use Encode;
@@ -128,14 +128,15 @@ has _bucket => (
 #pod
 #pod     $id = $stream->id;
 #pod
-#pod The generated L<MongoDB::OID> of the file created by the stream.  It will
-#pod be stored in the C<_id> field of the file document on a successful upload.
+#pod The id of the file created by the stream.  It will be stored in the C<_id>
+#pod field of the file document on a successful upload.  Some upload methods
+#pod require specifying an id at upload time.  Defaults to a newly-generated
+#pod L<MongoDB::OID>.
 #pod
 #pod =cut
 
 has id => (
     is  => 'lazy',
-    isa => InstanceOf ['MongoDB::OID'],
 );
 
 sub _build_id {
@@ -221,10 +222,10 @@ sub _flush_chunks {
     my ( $self, $all ) = @_;
     my @chunks = ();
     my $data;
-    while ( length $self->_buffer >= $self->chunk_size_bytes
-        || ( $all && length $self->_buffer > 0 ) )
+    while ( length $self->{_buffer} >= $self->chunk_size_bytes
+        || ( $all && length $self->{_buffer} > 0 ) )
     {
-        $data = substr $self->_buffer, 0, $self->chunk_size_bytes, '';
+        $data = substr $self->{_buffer}, 0, $self->chunk_size_bytes, '';
 
         push @chunks,
           {
@@ -248,7 +249,7 @@ sub _write_data {
     $self->{_buffer} .= $data;
     $self->{_length} += length $data;
     $self->_md5->add($data);
-    $self->_flush_chunks if length $self->_buffer >= $self->_chunk_buffer_length;
+    $self->_flush_chunks if length $self->{_buffer} >= $self->_chunk_buffer_length;
 }
 
 #pod =method abort
@@ -451,7 +452,7 @@ MongoDB::GridFSBucket::UploadStream - File handle abstraction for uploading
 
 =head1 VERSION
 
-version v1.3.4
+version v1.5.0
 
 =head1 SYNOPSIS
 
@@ -523,8 +524,10 @@ document on a successful upload.
 
     $id = $stream->id;
 
-The generated L<MongoDB::OID> of the file created by the stream.  It will
-be stored in the C<_id> field of the file document on a successful upload.
+The id of the file created by the stream.  It will be stored in the C<_id>
+field of the file document on a successful upload.  Some upload methods
+require specifying an id at upload time.  Defaults to a newly-generated
+L<MongoDB::OID>.
 
 =head2 fh
 
@@ -636,6 +639,10 @@ David Golden <david@mongodb.com>
 
 =item *
 
+Rassi <rassi@mongodb.com>
+
+=item *
+
 Mike Friedman <friedo@friedo.com>
 
 =item *
@@ -650,7 +657,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
