@@ -19,7 +19,7 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 use MongoDB;
@@ -51,6 +51,7 @@ use MongoDB::_Types qw(
     ArrayOfHashRef
     AuthMechanism
     BSONCodec
+    HeartbeatFreq
     NonNegNum
     ReadPrefMode
     ReadPreference
@@ -104,6 +105,41 @@ has host => (
     default => 'mongodb://localhost:27017',
 );
 
+#pod =attr app_name
+#pod
+#pod This attribute specifies an application name that should be associated with
+#pod this client.  The application name will be communicated to the server as
+#pod part of the initial connection handshake, and will appear in
+#pod connection-level and operation-level diagnostics on the server generated on
+#pod behalf of this client.  This may be set in a connection string with the
+#pod C<appName> option.
+#pod
+#pod The default is the empty string, which indicates a lack of an application
+#pod name.
+#pod
+#pod The application name must not exceed 128 bytes.
+#pod
+#pod =cut
+
+has app_name => (
+    is  => 'lazy',
+    isa => Str,
+    builder => '_build_app_name',
+);
+
+sub _build_app_name {
+    my ($self) = @_;
+    my $app_name = $self->__uri_or_else(
+        u => 'appname',
+        e => 'app_name',
+        d => '',
+    );
+    unless ( length($app_name) <= 128 ) {
+        MongoDB::UsageError->throw("app name must be at most 128 bytes");
+    }
+    return $app_name;
+}
+
 #pod =attr auth_mechanism
 #pod
 #pod This attribute determines how the client authenticates with the server.
@@ -288,7 +324,7 @@ sub _build_db_name {
 
 has heartbeat_frequency_ms => (
     is      => 'lazy',
-    isa     => NonNegNum,
+    isa     => HeartbeatFreq,
     builder => '_build_heartbeat_frequency_ms',
 );
 
@@ -362,6 +398,39 @@ sub _build_local_threshold_ms {
     );
 }
 
+#pod =attr max_staleness_ms
+#pod
+#pod The C<max_staleness_ms> parameter represents the maximum replication lag in
+#pod milliseconds (wall clock time) that a secondary can suffer and still be
+#pod eligible for reads. The default is zero, which disables staleness checks.
+#pod
+#pod If the read preference mode is 'primary', then C<max_staleness_ms> must not
+#pod be supplied.
+#pod
+#pod The C<max_staleness_ms> must be at least twice the C<heartbeat_frequency_ms>.
+#pod
+#pod B<Note>: this will only be used for server versions 3.4 or greater, as that
+#pod was when support for staleness tracking was added.
+#pod
+#pod This may be set in a connection string with the C<maxStalenessMS> option.
+#pod
+#pod =cut
+
+has max_staleness_ms => (
+    is      => 'lazy',
+    isa     => NonNegNum,
+    builder => '_build_max_staleness_ms',
+);
+
+sub _build_max_staleness_ms {
+    my ($self) = @_;
+    return $self->__uri_or_else(
+        u => 'maxstalenessms',
+        e => 'max_staleness_ms',
+        d => 0,
+    );
+}
+
 #pod =attr max_time_ms
 #pod
 #pod Specifies the maximum amount of time in (non-negative) milliseconds that the
@@ -973,6 +1042,7 @@ sub _build__read_preference {
     return MongoDB::ReadPreference->new(
         ( $self->read_pref_mode     ? ( mode     => $self->read_pref_mode )     : () ),
         ( $self->read_pref_tag_sets ? ( tag_sets => $self->read_pref_tag_sets ) : () ),
+        ( $self->max_staleness_ms ? ( max_staleness_ms => $self->max_staleness_ms ) : () ),
     );
 }
 
@@ -1067,13 +1137,14 @@ sub _build__topology {
 
     my $type =
         length( $self->replica_set_name ) ? 'ReplicaSetNoPrimary'
-      : @{ $self->_uri->hostpairs } > 1   ? 'Sharded'
+      : @{ $self->_uri->hostids } > 1   ? 'Sharded'
       :                                     'Single';
 
     MongoDB::_Topology->new(
         uri                         => $self->_uri,
         bson_codec                  => $self->bson_codec,
         type                        => $type,
+        app_name                    => $self->app_name,
         replica_set_name            => $self->replica_set_name,
         server_selection_timeout_sec => $self->server_selection_timeout_ms / 1000,
         server_selection_try_once    => $self->server_selection_try_once,
@@ -1138,6 +1209,7 @@ sub _build__uri {
 # these attributes are lazy, built from either _uri->options or from
 # _config_options captured in BUILDARGS
 my @deferred_options = qw(
+  app_name
   auth_mechanism
   auth_mechanism_properties
   connect_timeout_ms
@@ -1145,6 +1217,7 @@ my @deferred_options = qw(
   heartbeat_frequency_ms
   j
   local_threshold_ms
+  max_staleness_ms
   max_time_ms
   read_pref_mode
   read_pref_tag_sets
@@ -1179,7 +1252,7 @@ sub BUILD {
 
     my $uri = $self->_uri;
 
-    my @addresses = @{ $uri->hostpairs };
+    my @addresses = @{ $uri->hostids };
 
     # resolve and validate all deferred attributes
     $self->$_ for @deferred_options;
@@ -1386,7 +1459,7 @@ sub send_write_op {
     my ( $self, $op ) = @_;
     my ( $link, $result );
     ( $link = $self->{_topology}->get_writable_link ), (
-        eval { ($result) = $op->execute($link); 1 } or do {
+        eval { ($result) = $op->execute($link, $self->{_topology}->type); 1 } or do {
             my $err = length($@) ? $@ : "caught error, but it was lost in eval unwind";
             if ( $err->$_isa("MongoDB::ConnectionError") ) {
                 $self->{_topology}->mark_server_unknown( $link->server, $err );
@@ -1402,6 +1475,14 @@ sub send_write_op {
       return $result;
 }
 
+# Sometimes, seeing an op dispatched as "send_write_op" is confusing when
+# really, we're just insisting that it be sent only to a primary or
+# directly connected server.
+BEGIN {
+    no warnings 'once';
+    *send_primary_op = \&send_write_op;
+}
+
 # op dispatcher written in highly optimized style
 sub send_read_op {
     my ( $self, $op ) = @_;
@@ -1567,7 +1648,7 @@ sub fsync_unlock {
         bson_codec => $self->bson_codec,
     );
 
-    return $self->send_read_op($op);
+    return $self->send_primary_op($op);
 }
 
 
@@ -1585,7 +1666,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v1.3.4
+version v1.5.0
 
 =head1 SYNOPSIS
 
@@ -1660,6 +1741,20 @@ For IPv6 support, you must have a recent version of L<IO::Socket::IP>
 installed.  This module ships with the Perl core since v5.20.0 and is
 available on CPAN for older Perls.
 
+=head2 app_name
+
+This attribute specifies an application name that should be associated with
+this client.  The application name will be communicated to the server as
+part of the initial connection handshake, and will appear in
+connection-level and operation-level diagnostics on the server generated on
+behalf of this client.  This may be set in a connection string with the
+C<appName> option.
+
+The default is the empty string, which indicates a lack of an application
+name.
+
+The application name must not exceed 128 bytes.
+
 =head2 auth_mechanism
 
 This attribute determines how the client authenticates with the server.
@@ -1799,6 +1894,22 @@ See L</SERVER SELECTION> for more details.
 
 This may be set in a connection string with the C<localThresholdMS> option.
 
+=head2 max_staleness_ms
+
+The C<max_staleness_ms> parameter represents the maximum replication lag in
+milliseconds (wall clock time) that a secondary can suffer and still be
+eligible for reads. The default is zero, which disables staleness checks.
+
+If the read preference mode is 'primary', then C<max_staleness_ms> must not
+be supplied.
+
+The C<max_staleness_ms> must be at least twice the C<heartbeat_frequency_ms>.
+
+B<Note>: this will only be used for server versions 3.4 or greater, as that
+was when support for staleness tracking was added.
+
+This may be set in a connection string with the C<maxStalenessMS> option.
+
 =head2 max_time_ms
 
 Specifies the maximum amount of time in (non-negative) milliseconds that the
@@ -2347,6 +2458,7 @@ The currently supported connection string options are:
 
 =over 4
 
+*appName
 *authMechanism
 *authMechanism.SERVICE_NAME
 *connectTimeoutMS
@@ -2621,6 +2733,10 @@ David Golden <david@mongodb.com>
 
 =item *
 
+Rassi <rassi@mongodb.com>
+
+=item *
+
 Mike Friedman <friedo@friedo.com>
 
 =item *
@@ -2635,7 +2751,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
