@@ -19,36 +19,22 @@ package MongoDB::Op::_Aggregate;
 # Encapsulate aggregate operation; return MongoDB::QueryResult
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
-use MongoDB::Error;
 use MongoDB::Op::_Command;
-use MongoDB::_Constants;
 use MongoDB::_Types qw(
     ArrayOfHashRef
 );
 use Types::Standard qw(
+    Bool
     HashRef
     InstanceOf
-    Str
 );
-use boolean;
+
 use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
 has client => (
     is       => 'ro',
     required => 1,
@@ -67,9 +53,17 @@ has options => (
     isa      => HashRef,
 );
 
+has has_out => (
+    is       => 'ro',
+    required => 1,
+    isa      => Bool,
+);
+
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
+  MongoDB::Role::_CollectionOp
   MongoDB::Role::_ReadOp
+  MongoDB::Role::_WriteOp
   MongoDB::Role::_CommandCursorOp
 );
 
@@ -86,6 +80,11 @@ sub execute {
     # bypassDocumentValidation isn't available until 3.2 (wire version 4)
     delete $options->{bypassDocumentValidation} unless $link->accepts_wire_version(4);
 
+    if ( defined $options->{collation} and !$link->supports_collation ) {
+        MongoDB::UsageError->throw(
+            "MongoDB host '" . $link->address . "' doesn't support collation" );
+    }
+
     # If 'cursor' is explicitly false, we disable using cursors, even
     # for MongoDB 2.6+.  This allows users operating with a 2.6+ mongos
     # and pre-2.6 mongod in shards to avoid fatal errors.  This
@@ -117,35 +116,39 @@ sub execute {
         delete $options->{cursor};
     }
 
-    # read concerns are ignored if the last stage is $out
-    my ($last_op) = keys %{ $self->pipeline->[-1] };
+    my $has_out = $self->has_out;
 
     my @command = (
         aggregate => $self->coll_name,
         pipeline  => $self->pipeline,
-        ($last_op eq '$out' ? () :
-            ($link->accepts_wire_version(4) ?
-                @{ $self->read_concern->as_args } : () ) ),
         %$options,
+        (
+            !$has_out && $link->accepts_wire_version(4) ? @{ $self->read_concern->as_args } : ()
+        ),
+        (
+            $has_out && $link->accepts_wire_version(5) ? @{ $self->write_concern->as_args } : ()
+        ),
     );
 
     my $op = MongoDB::Op::_Command->_new(
         db_name         => $self->db_name,
         query           => Tie::IxHash->new(@command),
         query_flags     => {},
-        read_preference => $self->read_preference,
         bson_codec      => $self->bson_codec,
+        ( $has_out ? () : ( read_preference => $self->read_preference ) ),
     );
 
     my $res = $op->execute( $link, $topology );
 
+    $res->assert_no_write_concern_error if $has_out;
+
     # For explain, we give the whole response as fields have changed in
     # different server versions
     if ( $options->{explain} ) {
         return MongoDB::QueryResult->_new(
             _client       => $self->client,
             _address      => $link->address,
-            _ns           => '',
+            _full_name    => '',
             _bson_codec   => $self->bson_codec,
             _batch_size   => 1,
             _cursor_at    => 0,
