@@ -20,43 +20,19 @@ package MongoDB::Op::_BatchInsert;
 # MongoDB::InsertManyResult
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
-use MongoDB::BSON;
-use MongoDB::Error;
 use MongoDB::InsertManyResult;
-use MongoDB::OID;
-use MongoDB::_Constants;
-use MongoDB::_Protocol;
+use Tie::IxHash;
 use Types::Standard qw(
-    Str
     ArrayRef
     Bool
 );
-use Scalar::Util qw/blessed reftype/;
-use Tie::IxHash;
+
 use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has full_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
 # may or may not have _id; will be added if check_keys is true
 has documents => (
     is       => 'ro',
@@ -86,7 +62,8 @@ has _doc_ids => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_WriteCommand
+  MongoDB::Role::_CollectionOp
+  MongoDB::Role::_SingleBatchDocWrite
   MongoDB::Role::_InsertPreEncoder
 );
 
