@@ -20,7 +20,7 @@ package MongoDB::Op::_BulkWrite;
 # MongoDB::BulkWriteResult object
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
@@ -36,27 +36,13 @@ use MongoDB::_Constants;
 use Types::Standard qw(
     ArrayRef
     Bool
-    Str
 );
 use Safe::Isa;
-use Scalar::Util qw/blessed reftype/;
-use Tie::IxHash;
 use Try::Tiny;
 use boolean;
+
 use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
 has queue => (
     is       => 'ro',
     required => 1,
@@ -69,20 +55,38 @@ has ordered => (
     isa      => Bool,
 );
 
-# not _WriteCommand because we construct our own results objects
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
+  MongoDB::Role::_CollectionOp
   MongoDB::Role::_WriteOp
   MongoDB::Role::_UpdatePreEncoder
   MongoDB::Role::_InsertPreEncoder
   MongoDB::Role::_BypassValidation
 );
 
+sub has_collation {
+    my $self = shift;
+    return !!grep {
+        my ( $type, $doc ) = @$_;
+        ( $type eq "update" || $type eq "delete" ) && defined $doc->{collation};
+    } @{ $self->queue };
+}
+
 sub execute {
     my ( $self, $link ) = @_;
 
     Carp::confess("NO LINK") unless $link;
 
+    if ( $self->has_collation ) {
+        MongoDB::UsageError->throw(
+            "MongoDB host '" . $link->address . "' doesn't support collation" )
+          if !$link->supports_collation;
+
+        MongoDB::UsageError->throw(
+            "Unacknowledged bulk writes that specify a collation are not allowed")
+          if !$self->write_concern->is_acknowledged;
+    }
+
     my $use_write_cmd = $link->does_write_commands;
 
     # If using legacy write ops, then there will never be a valid modified_count
