@@ -19,26 +19,21 @@ package MongoDB::Op::_Command;
 # Encapsulate running a command and returning a MongoDB::CommandResult
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
 use MongoDB::_Constants;
 use MongoDB::_Types qw(
     Document
+    ReadPreference
 );
 use Types::Standard qw(
     HashRef
-    Str
+    Maybe
 );
-use Tie::IxHash;
-use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
+use namespace::clean;
 
 has query => (
     is       => 'ro',
@@ -53,9 +48,14 @@ has query_flags => (
     isa      => HashRef,
 );
 
+has read_preference => (
+    is  => 'ro',
+    isa => Maybe [ReadPreference],
+);
+
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_ReadOp
+  MongoDB::Role::_DatabaseOp
   MongoDB::Role::_ReadPrefModifier
 );
 
