@@ -19,25 +19,15 @@ package MongoDB::Op::_Count;
 # Encapsulate code path for count commands
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
 use MongoDB::Op::_Command;
-use MongoDB::Error;
-
-use MongoDB::_Types qw(
-    Document
-);
-
 use Types::Standard qw(
-    Str
-    InstanceOf
     HashRef
 );
 
-use Tie::IxHash;
-use boolean;
 use namespace::clean;
 
 has filter => (
@@ -52,26 +42,20 @@ has options => (
     isa => HashRef,
 );
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa => Str,
-);
-
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
+  MongoDB::Role::_CollectionOp
   MongoDB::Role::_ReadOp
 );
 
 sub execute {
     my ( $self, $link, $topology ) = @_;
 
+    if ( defined $self->options->{collation} and !$link->supports_collation ) {
+        MongoDB::UsageError->throw(
+            "MongoDB host '" . $link->address . "' doesn't support collation" );
+    }
+
     my $command = [
         count => $self->coll_name,
         query => $self->filter,
