@@ -20,35 +20,20 @@ package MongoDB::Op::_CreateIndexes;
 # or a MongoDB::InsertManyResult, depending on the server version
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
-use MongoDB::CommandResult;
-use MongoDB::_Constants;
-use MongoDB::_Types -types;
 use MongoDB::Op::_Command;
 use MongoDB::Op::_BatchInsert;
 use Types::Standard qw(
     ArrayRef
+    Bool
     HashRef
-    Str
 );
-use Tie::IxHash;
+
 use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
 has indexes => (
     is       => 'ro',
     required => 1,
@@ -57,19 +42,27 @@ has indexes => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
+  MongoDB::Role::_CollectionOp
   MongoDB::Role::_WriteOp
 );
 
+sub has_collation {
+    return grep { defined $_->{collation} } @{ $_[0]->indexes };
+}
+
 sub execute {
     my ( $self, $link ) = @_;
 
+    if ( $self->has_collation && !$link->supports_collation ) {
+        MongoDB::UsageError->throw(
+            "MongoDB host '" . $link->address . "' doesn't support collation" );
+    }
+
     my $res =
         $link->does_write_commands
       ? $self->_command_create_indexes($link)
       : $self->_legacy_index_insert($link);
 
-    $res->assert;
-
     return $res;
 }
 
@@ -77,13 +70,20 @@ sub _command_create_indexes {
     my ( $self, $link, $op_doc ) = @_;
 
     my $op = MongoDB::Op::_Command->_new(
-        db_name         => $self->db_name,
-        query           => [ createIndexes => $self->coll_name, indexes => $self->indexes, ],
-        query_flags     => {},
-        bson_codec      => $self->bson_codec,
+        db_name => $self->db_name,
+        query   => [
+            createIndexes => $self->coll_name,
+            indexes       => $self->indexes,
+            ( $link->accepts_wire_version(5) ? ( @{ $self->write_concern->as_args } ) : () )
+        ],
+        query_flags => {},
+        bson_codec  => $self->bson_codec,
     );
 
-    return $op->execute( $link );
+    my $res = $op->execute( $link );
+    $res->assert_no_write_concern_error;
+
+    return $res;
 }
 
 sub _legacy_index_insert {
