@@ -19,42 +19,22 @@ package MongoDB::Op::_Delete;
 # Encapsulate a delete operation; returns a MongoDB::DeleteResult
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
-use MongoDB::BSON;
 use MongoDB::DeleteResult;
-use MongoDB::_Constants;
 use MongoDB::_Protocol;
 use MongoDB::_Types qw(
     Document
 );
 use Types::Standard qw(
     Bool
-    Str
+    Maybe
 );
-use Tie::IxHash;
+
 use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has full_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
 has filter => (
     is       => 'ro',
     required => 1,
@@ -67,20 +47,39 @@ has just_one => (
     isa      => Bool,
 );
 
+has collation => (
+    is       => 'ro',
+    isa      => Maybe( [Document] ),
+);
+
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_WriteCommand
+  MongoDB::Role::_CollectionOp
+  MongoDB::Role::_SingleBatchDocWrite
 );
 
 sub execute {
     my ( $self, $link ) = @_;
 
+    if ( defined $self->collation ) {
+        MongoDB::UsageError->throw(
+            "MongoDB host '" . $link->address . "' doesn't support collation" )
+          if !$link->supports_collation;
+        MongoDB::UsageError->throw(
+            "Unacknowledged deletes that specify a collation are not allowed")
+          if !$self->write_concern->is_acknowledged;
+    }
+
     my $filter =
       ref( $self->filter ) eq 'ARRAY'
       ? { @{ $self->filter } }
       : $self->filter;
 
-    my $op_doc = { q => $filter, limit => $self->just_one ? 1 : 0 };
+    my $op_doc = {
+        q     => $filter,
+        limit => $self->just_one ? 1 : 0,
+        ( defined $self->collation ? ( collation => $self->collation ) : () ),
+    };
 
     return (
         ! $self->write_concern->is_acknowledged
