@@ -19,12 +19,11 @@ package MongoDB::Op::_Distinct;
 # Encapsulate distinct operation; return MongoDB::QueryResult
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
 use MongoDB::Op::_Command;
-use MongoDB::_Constants;
 use MongoDB::_Types qw(
     Document
 );
@@ -33,20 +32,9 @@ use Types::Standard qw(
     HashRef
     Str
 );
+
 use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa => Str,
-);
-
 has client => (
     is       => 'ro',
     required => 1,
@@ -73,6 +61,7 @@ has options => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
+  MongoDB::Role::_CollectionOp
   MongoDB::Role::_ReadOp
   MongoDB::Role::_CommandCursorOp
 );
@@ -82,6 +71,11 @@ sub execute {
 
     my $options = $self->options;
 
+    if ( defined $options->{collation} and !$link->supports_collation ) {
+        MongoDB::UsageError->throw(
+            "MongoDB host '" . $link->address . "' doesn't support collation" );
+    }
+
     my $filter =
       ref( $self->filter ) eq 'ARRAY'
       ? { @{ $self->filter } }
