@@ -20,30 +20,23 @@ package MongoDB::Op::_FSyncUnlock;
 # names
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
 use MongoDB::Op::_Command;
 use MongoDB::Op::_Query;
-use MongoDB::QueryResult::Filtered;
-use MongoDB::_Constants;
+use MongoDB::ReadConcern;
+use MongoDB::ReadPreference;
 use MongoDB::_Types qw(
     Document
 );
 use Types::Standard qw(
-    HashRef
     InstanceOf
-    Str
 );
 use Tie::IxHash;
-use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa => Str,
-);
+use namespace::clean;
 
 has client => (
     is       => 'ro',
@@ -53,8 +46,7 @@ has client => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_ReadOp
-  MongoDB::Role::_CommandCursorOp
+  MongoDB::Role::_DatabaseOp
 );
 
 sub execute {
@@ -79,7 +71,7 @@ sub _command_fsync_unlock {
         db_name         => $self->db_name,
         query           => $cmd,
         query_flags     => {},
-        read_preference => $self->read_preference,
+        read_preference => MongoDB::ReadPreference->new,
         bson_codec      => $self->bson_codec,
     );
 
@@ -91,7 +83,7 @@ sub _command_fsync_unlock {
 sub _legacy_fsync_unlock {
     my ( $self, $link, $topology ) = @_;
 
-    my $query = MongoDB::_Query->_new(
+    my $op = MongoDB::Op::_Query->_new(
         modifiers           => {},
         filter              => {},
         allowPartialResults => 0,
@@ -107,14 +99,14 @@ sub _legacy_fsync_unlock {
         sort                => undef,
         db_name             => 'admin',
         coll_name           => '$cmd.sys.unlock',
+        full_name           => 'admin.$cmd.sys.unlock',
         limit               => -1,
         bson_codec          => $self->bson_codec,
         client              => $self->client,
-        read_preference     => $self->read_preference,
+        read_preference     => MongoDB::ReadPreference->new,
+        read_concern        => MongoDB::ReadConcern->new,
     );
 
-    my $op = $query->as_query_op();
-
     return $op->execute( $link, $topology )->next;
 }
 
