@@ -19,45 +19,20 @@ package MongoDB::Op::_FindAndDelete;
 # Encapsulate find_and_delete operation; atomically delete and return doc
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
-use boolean;
 use MongoDB::Error;
 use MongoDB::Op::_Command;
 use Types::Standard qw(
-    InstanceOf
-    Str
     HashRef
-    Maybe
 );
-
-use MongoDB::_Types qw(
-    WriteConcern
-);
-
 use Try::Tiny;
+use boolean;
+
 use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has client => (
-    is       => 'ro',
-    required => 1,
-    isa      => InstanceOf ['MongoDB::MongoClient'],
-);
-
 has filter => (
     is       => 'ro',
     required => 1,
@@ -70,21 +45,20 @@ has options => (
     isa      => HashRef,
 );
 
-has write_concern => (
-    is       => 'ro',
-    required => 1,
-    isa      => WriteConcern,
-);
-
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_ReadOp
-  MongoDB::Role::_CommandCursorOp
+  MongoDB::Role::_CollectionOp
+  MongoDB::Role::_WriteOp
 );
 
 sub execute {
     my ( $self, $link, $topology ) = @_;
 
+    if ( defined $self->options->{collation} and !$link->supports_collation ) {
+        MongoDB::UsageError->throw(
+            "MongoDB host '" . $link->address . "' doesn't support collation" );
+    }
+
     my $command = [
         findAndModify   => $self->coll_name,
         query           => $self->filter,
