@@ -19,16 +19,15 @@ package MongoDB::Op::_KillCursors;
 # Encapsulate a cursor kill operation; returns true
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
-use MongoDB::_Constants;
+use MongoDB::_Protocol;
 use Types::Standard qw(
     ArrayRef
-    Str
 );
-use MongoDB::_Protocol;
+
 use namespace::clean;
 
 has cursor_ids => (
