@@ -19,17 +19,17 @@ package MongoDB::Op::_Query;
 # Encapsulate a query operation; returns a MongoDB::QueryResult object
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
+use boolean;
 use Moo;
 
 use List::Util qw/min/;
-use MongoDB::BSON;
 use MongoDB::QueryResult;
+use MongoDB::QueryResult::Filtered;
 use MongoDB::_Constants;
 use MongoDB::_Protocol;
 use MongoDB::_Types qw(
-    BSONCodec
     Document
     CursorType
     IxHash
@@ -44,82 +44,118 @@ use Types::Standard qw(
     Str
 );
 use boolean;
+
 use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
 has client => (
     is       => 'ro',
     required => 1,
     isa      => InstanceOf ['MongoDB::MongoClient'],
 );
 
-has projection => (
-    is       => 'ro',
-    isa      => Maybe [Document],
-);
+#--------------------------------------------------------------------------#
+# Attributes based on the CRUD API spec: filter
+#
+# Some are mutable so that MongoDB::Cursor methods can manipulate them
+# until the query is executed
+#
+# Unlike most parameters, these are camelCase so that find method options
+# may be passed through directly.
+#--------------------------------------------------------------------------#
 
-has [qw/batch_size limit skip/] => (
-    is       => 'ro',
-    required => 1,
-    isa      => Num,
-);
-
-has sort => (
-    is  => 'ro',
-    isa => Maybe( [IxHash] ),
-);
+# Immutable attributes
 
 has filter => (
     is       => 'ro',
     isa      => Document,
+    required => 1,
 );
 
-has comment => (
-    is       => 'ro',
-    isa      => Str,
-);
-
-has max_await_time_ms => (
-    is       => 'ro',
-    isa      => Maybe[Num],
-);
-
-has max_time_ms => (
-    is       => 'ro',
-    isa      => Maybe[Num],
-);
-
-has no_cursor_timeout => (
-    is       => 'ro',
-    isa      => Bool,
-);
-
-has allow_partial_results => (
-    is       => 'ro',
-    isa      => Bool,
-);
+# Immutable attribute, but mutable hash.  We require it to be provided as
+# we allow a private constructor so can't rely on a default.
 
 has modifiers => (
     is  => 'ro',
     isa => HashRef,
+    required => 1,
 );
 
-has cursor_type => (
-    is       => 'ro',
+# Mutable attributes, due to legacy behavior of MongoDB::Cursor that allows
+# modifying a deferred query operation before executing it.
+
+has allowPartialResults => (
+    is       => 'rw',
+    isa      => Bool,
+    required => 1,
+);
+
+has batchSize => (
+    is       => 'rw',
+    isa      => Num,
+    required => 1,
+);
+
+has comment => (
+    is       => 'rw',
+    isa      => Str,
+    required => 1,
+);
+
+has cursorType => (
+    is       => 'rw',
     isa      => CursorType,
+    required => 1,
 );
 
+has limit => (
+    is       => 'rw',
+    isa      => Num,
+    required => 1,
+);
+
+has maxAwaitTimeMS => (
+    is       => 'rw',
+    isa      => Num,
+    required => 1,
+);
+
+has maxTimeMS => (
+    is       => 'rw',
+    isa      => Num,
+    required => 1,
+);
+
+has noCursorTimeout => (
+    is       => 'rw',
+    isa      => Bool,
+    required => 1,
+);
+
+has skip => (
+    is       => 'rw',
+    isa      => Num,
+    required => 1,
+);
+
+# optional attributes
+
+has projection => (
+    is  => 'rw',
+    isa => Maybe( [Document] ),
+);
+
+has sort => (
+    is  => 'rw',
+    isa => Maybe( [IxHash] ),
+);
+
+has collation => (
+    is  => 'rw',
+    isa => Maybe( [Document] ),
+);
+
+# Not a MongoDB query attribute; this is used during construction of a
+# result object
 has post_filter => (
     is        => 'ro',
     predicate => 'has_post_filter',
@@ -128,15 +164,21 @@ has post_filter => (
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
+  MongoDB::Role::_CollectionOp
   MongoDB::Role::_ReadOp
   MongoDB::Role::_CommandCursorOp
   MongoDB::Role::_OpReplyParser
+  MongoDB::Role::_ReadPrefModifier
 );
-with 'MongoDB::Role::_ReadPrefModifier';
 
 sub execute {
     my ( $self, $link, $topology ) = @_;
 
+    if ( defined $self->collation and !$link->supports_collation ) {
+        MongoDB::UsageError->throw(
+            "MongoDB host '" . $link->address . "' doesn't support collation" );
+    }
+
     my $res =
         $link->accepts_wire_version(4)
       ? $self->_command_query( $link, $topology )
@@ -164,10 +206,10 @@ sub _legacy_query {
     my ( $self, $link, $topology ) = @_;
 
     my $query_flags = {
-        tailable => ( $self->cursor_type =~ /^tailable/ ? 1 : 0 ),
-        await_data => $self->cursor_type eq 'tailable_await',
-        immortal => $self->no_cursor_timeout,
-        partial => $self->allow_partial_results,
+        tailable => ( $self->cursorType =~ /^tailable/ ? 1 : 0 ),
+        await_data => $self->cursorType eq 'tailable_await',
+        immortal => $self->noCursorTimeout,
+        partial => $self->allowPartialResults,
     };
 
     # build starting query document; modifiers come first as other parameters
@@ -177,8 +219,8 @@ sub _legacy_query {
         ( $self->comment ? ( '$comment' => $self->comment ) : () ),
         ( $self->sort    ? ( '$orderby' => $self->sort )    : () ),
         (
-              ( $self->max_time_ms && $self->coll_name !~ /\A\$cmd/ )
-            ? ( '$maxTimeMS' => $self->max_time_ms )
+              ( $self->maxTimeMS && $self->coll_name !~ /\A\$cmd/ )
+            ? ( '$maxTimeMS' => $self->maxTimeMS )
             : ()
         ),
         '$query' => ($self->filter || {}),
@@ -195,12 +237,12 @@ sub _legacy_query {
         : exists $query->{'$query'}{query}
       );
 
-    my $ns         = $self->db_name . "." . $self->coll_name;
+    my $full_name  = $self->full_name;
     my $filter     = $self->bson_codec->encode_one( $query );
 
     # rules for calculating initial batch size
     my $limit      = $self->limit      || 0;
-    my $batch_size = $self->batch_size || 0;
+    my $batch_size = $self->batchSize || 0;
     my $n_to_return =
         $limit == 0      ? $batch_size
       : $batch_size == 0 ? $limit
@@ -214,7 +256,7 @@ sub _legacy_query {
     $self->_apply_read_prefs( $link, $topology, $query_flags, \$query);
 
     my ( $op_bson, $request_id ) =
-      MongoDB::_Protocol::write_query( $ns, $filter, $proj, $self->skip, $n_to_return,
+      MongoDB::_Protocol::write_query( $full_name, $filter, $proj, $self->skip, $n_to_return,
         $query_flags );
 
     my $result =
@@ -226,7 +268,7 @@ sub _legacy_query {
     return $class->_new(
         _client       => $self->client,
         _address      => $link->address,
-        _ns           => $ns,
+        _full_name    => $full_name,
         _bson_codec   => $self->bson_codec,
         _batch_size   => $n_to_return,
         _cursor_at    => 0,
@@ -247,15 +289,15 @@ my $FALSE = boolean::false();
 sub as_command {
     my ($self) = @_;
 
-    my ($limit, $batch_size, $single_batch) = ($self->{limit}, $self->{batch_size}, 0);
+    my ($limit, $batch_size, $single_batch) = ($self->{limit}, $self->{batchSize}, 0);
 
     $single_batch = $limit < 0 || $batch_size < 0;
     $limit = abs($limit);
     $batch_size = $limit if $single_batch;
 
-    my $tailable = $self->{cursor_type} =~ /^tailable/ ? $TRUE : $FALSE;
-    my $await_data = $self->{cursor_type} eq 'tailable_await' ? $TRUE : $FALSE;
-    my $max_time = $await_data ? $self->{max_await_time_ms} : $self->{max_time_ms} ;
+    my $tailable = $self->{cursorType} =~ /^tailable/ ? $TRUE : $FALSE;
+    my $await_data = $self->{cursorType} eq 'tailable_await' ? $TRUE : $FALSE;
+    my $max_time = $await_data ? $self->{maxAwaitTimeMS} : $self->{maxTimeMS} ;
 
     my $mod = $self->{modifiers};
 
@@ -265,6 +307,7 @@ sub as_command {
 
         (defined $self->{sort} ? (sort => $self->{sort}) : ()),
         (defined $self->{projection} ? (projection => $self->{projection}) : ()),
+        (defined $self->{collation} ? (collation => $self->{collation}) : ()),
         (defined $mod->{'$hint'} ? (hint => $mod->{'$hint'}) : ()),
 
         skip                => $self->{skip},
@@ -275,21 +318,45 @@ sub as_command {
         singleBatch         => ($single_batch ? $TRUE : $FALSE),
 
         ($self->{comment} ? (comment => $self->{comment}) : ()),
-        (defined $mod->{maxScan} ? (maxScan => $mod->{maxScan}) : ()),
-        (defined $self->{max_time_ms} ? (maxTimeMS => $self->{max_time_ms}) : ()),
-        (defined $mod->{max} ? (max => $mod->{max}) : ()),
-        (defined $mod->{min} ? (min => $mod->{min}) : ()),
-        (defined $mod->{returnKey} ? (returnKey => $mod->{returnKey}) : ()),
-        (defined $mod->{showDiskLoc} ? (showRecordId => $mod->{showDiskLoc}) : ()),
-        (defined $mod->{snapshot} ? (snapshot => $mod->{snapshot}) : ()),
+        (defined $mod->{'$maxScan'} ? (maxScan => $mod->{'$maxScan'}) : ()),
+        (defined $self->{maxTimeMS} ? (maxTimeMS => $self->{maxTimeMS}) : ()),
+        (defined $mod->{'$max'} ? (max => $mod->{'$max'}) : ()),
+        (defined $mod->{'$min'} ? (min => $mod->{'$min'}) : ()),
+        (defined $mod->{'$returnKey'} ? (returnKey => $mod->{'$returnKey'}) : ()),
+        (defined $mod->{'$showDiskLoc'} ? (showRecordId => $mod->{'$showDiskLoc'}) : ()),
+        (defined $mod->{'$snapshot'} ? (snapshot => boolean($mod->{'$snapshot'})) : ()),
 
         tailable            => $tailable,
-        noCursorTimeout     =>($self->{no_cursor_timeout} ? $TRUE : $FALSE),
+        noCursorTimeout     =>($self->{noCursorTimeout} ? $TRUE : $FALSE),
         awaitData           => $await_data,
-        allowPartialResults =>($self->{allow_partial_results} ? $TRUE : $FALSE ),
+        allowPartialResults =>($self->{allowPartialResults} ? $TRUE : $FALSE ),
 
         @{$self->{read_concern}->as_args},
     ];
 }
 
+sub clone {
+    my ($self) = @_;
+
+    # shallow copy everything;
+    my %args = %$self;
+
+    # deep copy any documents
+    for my $k (qw/filter modifiers projection sort/) {
+        my ($orig ) = $args{$k};
+        next unless $orig;
+        if ( ref($orig) eq 'Tie::IxHash' ) {
+          $args{$k}= Tie::IxHash->new( map { $_ => $orig->FETCH($_) } $orig->Keys );
+        }
+        elsif ( ref($orig) eq 'ARRAY' ) {
+         $args{$k}= [@$orig];
+        }
+        else {
+         $args{$k} = { %$orig };
+        }
+    }
+
+    return ref($self)->_new(%args);
+}
+
 1;
