@@ -19,43 +19,24 @@ package MongoDB::Op::_Update;
 # Encapsulate an update operation; returns a MongoDB::UpdateResult
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 
-use MongoDB::BSON;
 use MongoDB::UpdateResult;
-use MongoDB::_Constants;
 use MongoDB::_Protocol;
 use MongoDB::_Types qw(
     Document
 );
 use Types::Standard qw(
     Bool
-    Str
+    Maybe
 );
 use Tie::IxHash;
 use boolean;
+
 use namespace::clean;
 
-has db_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has coll_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
-has full_name => (
-    is       => 'ro',
-    required => 1,
-    isa      => Str,
-);
-
 has filter => (
     is       => 'ro',
     required => 1,
@@ -83,9 +64,15 @@ has upsert => (
     is       => 'ro',
 );
 
+has collation => (
+    is       => 'ro',
+    isa      => Maybe( [Document] ),
+);
+
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_WriteCommand
+  MongoDB::Role::_CollectionOp
+  MongoDB::Role::_SingleBatchDocWrite
   MongoDB::Role::_UpdatePreEncoder
   MongoDB::Role::_BypassValidation
 );
@@ -96,6 +83,15 @@ my ($true, $false) = (true, false);
 sub execute {
     my ( $self, $link ) = @_;
 
+    if ( defined $self->collation ) {
+        MongoDB::UsageError->throw(
+            "MongoDB host '" . $link->address . "' doesn't support collation" )
+          if !$link->supports_collation;
+        MongoDB::UsageError->throw(
+            "Unacknowledged updates that specify a collation are not allowed")
+          if !$self->write_concern->is_acknowledged;
+    }
+
     my $orig_op = {
         q => (
             ref( $self->filter ) eq 'ARRAY'
@@ -105,6 +101,7 @@ sub execute {
         u      => $self->update,
         multi  => $self->multi ? $true : $false,
         upsert => $self->upsert ? $true : $false,
+        ( defined $self->collation ? ( collation => $self->collation ) : () ),
     };
 
     return ! $self->write_concern->is_acknowledged
