@@ -19,7 +19,7 @@ package MongoDB::QueryResult;
 # ABSTRACT: An iterator for Mongo query results
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 use MongoDB::Error;
@@ -44,7 +44,7 @@ use namespace::clean;
 
 with $_ for qw(
   MongoDB::Role::_PrivateConstructor
-  MongoDB::Role::_Cursor
+  MongoDB::Role::_CursorAPI
 );
 
 # attributes needed for get more
@@ -61,7 +61,7 @@ has _address => (
     isa => HostAddress,
 );
 
-has _ns => (
+has _full_name => (
     is       => 'ro',
     required => 1,
     isa => Str,
@@ -230,10 +230,10 @@ sub _get_more {
     my $limit = $self->_limit;
     my $want = $limit > 0 ? ( $limit - $self->_cursor_at ) : $self->_batch_size;
 
-    my ($db_name, $coll_name) = split(/\./, $self->_ns, 2);
+    my ($db_name, $coll_name) = split(/\./, $self->_full_name, 2);
 
     my $op = MongoDB::Op::_GetMore->_new(
-        ns          => $self->_ns,
+        full_name   => $self->_full_name,
         db_name     => $db_name,
         coll_name   => $coll_name,
         client      => $self->_client,
@@ -335,7 +335,7 @@ MongoDB::QueryResult - An iterator for Mongo query results
 
 =head1 VERSION
 
-version v1.3.4
+version v1.5.0
 
 =head1 SYNOPSIS
 
@@ -420,6 +420,10 @@ David Golden <david@mongodb.com>
 
 =item *
 
+Rassi <rassi@mongodb.com>
+
+=item *
+
 Mike Friedman <friedo@friedo.com>
 
 =item *
@@ -434,7 +438,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
