@@ -19,12 +19,13 @@ package MongoDB::ReadPreference;
 # ABSTRACT: Encapsulate and validate read preferences
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 use MongoDB::Error;
 use MongoDB::_Types qw(
     ArrayOfHashRef
+    NonNegNum
     ReadPrefMode
 );
 use namespace::clean -except => 'meta';
@@ -72,6 +73,22 @@ has tag_sets => (
     coerce  => ArrayOfHashRef->coercion,
 );
 
+#pod =attr max_staleness_ms
+#pod
+#pod The C<max_staleness_ms> parameter represents the maximum replication lag in
+#pod milliseconds (wall clock time) that a secondary can suffer and still be
+#pod eligible for reads. The default is zero, which disables staleness checks.
+#pod
+#pod If the C<mode> is 'primary', then C<max_staleness_ms> must not be supplied.
+#pod
+#pod =cut
+
+has max_staleness_ms => (
+    is => 'ro',
+    isa => NonNegNum,
+    default => 0,
+);
+
 sub BUILD {
     my ($self) = @_;
 
@@ -79,6 +96,10 @@ sub BUILD {
         MongoDB::UsageError->throw("A tag set list is not allowed with read preference mode 'primary'");
     }
 
+    if ( $self->mode eq 'primary' && $self->max_staleness_ms ) {
+        MongoDB::UsageError->throw("A positive max_staleness_ms is not allowed with read preference mode 'primary'");
+    }
+
     return;
 }
 
@@ -97,7 +118,8 @@ sub for_mongos {
     my ($self) = @_;
     return {
         mode => $self->mode,
-        tags => $self->tag_sets,
+        ( $self->has_empty_tag_sets ? () : ( tags => $self->tag_sets ) ),
+        ( $self->max_staleness_ms > 0 ? ( maxStalenessMS => $self->max_staleness_ms ) : () ),
     };
 }
 
@@ -113,6 +135,9 @@ sub as_string {
         }
         $string .= " (" . join( ",", map { "{$_}" } @ts ) . ")";
     }
+    if ( $self->max_staleness_ms > 0) {
+        $string .= " ( maxStalenessMS: " . $self->max_staleness_ms . " )";
+    }
     return $string;
 }
 
@@ -131,7 +156,7 @@ MongoDB::ReadPreference - Encapsulate and validate read preferences
 
 =head1 VERSION
 
-version v1.3.4
+version v1.5.0
 
 =head1 SYNOPSIS
 
@@ -271,6 +296,14 @@ eligibility of servers, such as for data center awareness.
 The application of C<tag_sets> varies depending on the C<mode> parameter.  If
 the C<mode> is 'primary', then C<tag_sets> must not be supplied.
 
+=head2 max_staleness_ms
+
+The C<max_staleness_ms> parameter represents the maximum replication lag in
+milliseconds (wall clock time) that a secondary can suffer and still be
+eligible for reads. The default is zero, which disables staleness checks.
+
+If the C<mode> is 'primary', then C<max_staleness_ms> must not be supplied.
+
 =for Pod::Coverage has_empty_tag_sets for_mongos as_string
 
 =head1 AUTHORS
@@ -283,6 +316,10 @@ David Golden <david@mongodb.com>
 
 =item *
 
+Rassi <rassi@mongodb.com>
+
+=item *
+
 Mike Friedman <friedo@friedo.com>
 
 =item *
@@ -297,7 +334,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by MongoDB, Inc..
+This software is Copyright (c) 2016 by MongoDB, Inc.
 
 This is free software, licensed under:
 
