@@ -19,11 +19,12 @@ package MongoDB::Role::_CommandCursorOp;
 # MongoDB interface for database commands with cursors
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
+
+use Moo::Role;
 
 use MongoDB::Error;
 use MongoDB::QueryResult;
-use Moo::Role;
 
 use namespace::clean;
 
@@ -40,15 +41,15 @@ sub _build_result_from_cursor {
 
     my $max_time_ms = undef;
     if ($self->isa('MongoDB::Op::_Query') &&
-        $self->cursor_type eq 'tailable_await') {
-        $max_time_ms = $self->max_await_time_ms if defined $self->max_await_time_ms;
+        $self->cursorType eq 'tailable_await') {
+        $max_time_ms = $self->maxAwaitTimeMS if $self->maxAwaitTimeMS;
     }
 
     my $batch = $c->{firstBatch};
     my $qr = MongoDB::QueryResult->_new(
-        _client      => $self->client,
+        _client       => $self->client,
         _address      => $res->address,
-        _ns           => $c->{ns},
+        _full_name    => $c->{ns},
         _bson_codec   => $self->bson_codec,
         _batch_size   => scalar @$batch,
         _cursor_at    => 0,
@@ -57,8 +58,8 @@ sub _build_result_from_cursor {
         _cursor_start => 0,
         _cursor_flags => {},
         _cursor_num   => scalar @$batch,
-        _docs        => $batch,
-        defined $max_time_ms ? (_max_time_ms => $max_time_ms) : (),
+        _docs         => $batch,
+        defined $max_time_ms ? ( _max_time_ms => $max_time_ms ) : (),
     );
 }
 
@@ -66,9 +67,9 @@ sub _empty_query_result {
     my ( $self, $link ) = @_;
 
     my $qr = MongoDB::QueryResult->_new(
-        _client      => $self->client,
+        _client       => $self->client,
         _address      => $link->address,
-        _ns           => '',
+        _full_name    => '',
         _bson_codec   => $self->bson_codec,
         _batch_size   => 1,
         _cursor_at    => 0,
@@ -77,7 +78,7 @@ sub _empty_query_result {
         _cursor_start => 0,
         _cursor_flags => {},
         _cursor_num   => 0,
-        _docs        => [],
+        _docs         => [],
     );
 }
 
