@@ -19,11 +19,13 @@ package MongoDB::Role::_InsertPreEncoder;
 # MongoDB interface for pre-encoding and validating docs to insert
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo::Role;
-use MongoDB::Error;
+
 use MongoDB::BSON::_EncodedDoc;
+use MongoDB::OID;
+
 use namespace::clean;
 
 requires qw/bson_codec/;
