@@ -20,12 +20,14 @@ package MongoDB::Role::_WriteOp;
 # or other things that take a write concern)
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
+
+use Moo::Role;
 
 use MongoDB::_Types qw(
     WriteConcern
 );
-use Moo::Role;
+
 use namespace::clean;
 
 has write_concern => (
@@ -34,8 +36,4 @@ has write_concern => (
     isa => WriteConcern,
 );
 
-with $_ for qw(
-  MongoDB::Role::_BSONCodec
-);
-
 1;
