@@ -19,14 +19,16 @@ package MongoDB::Role::_WriteResult;
 # MongoDB interface for common write result attributes and methods
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
+
+use Moo::Role;
 
 use MongoDB::Error;
 use MongoDB::_Constants;
 use MongoDB::_Types qw(
     ArrayOfHashRef
 );
-use Moo::Role;
+
 use namespace::clean;
 
 has [qw/write_errors write_concern_errors/] => (
@@ -35,7 +37,7 @@ has [qw/write_errors write_concern_errors/] => (
     isa      => ArrayOfHashRef,
 );
 
-with 'MongoDB::Role::_LastError';
+with 'MongoDB::Role::_DatabaseErrorThrower';
 
 sub acknowledged() { 1 }; # override to 0 for MongoDB::UnacknowledgedResult
 
