@@ -25,7 +25,7 @@ use warnings;
 package MongoDB::_Link;
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 use Errno qw[EINTR EPIPE];
@@ -122,6 +122,13 @@ has does_write_commands => (
     isa => Bool,
 );
 
+# for caching wire version >= 5
+has supports_collation => (
+    is => 'rwp',
+    init_arg => undef,
+    isa => Bool,
+);
+
 my @connection_state_fields = qw(
     fh connected rcvbuf last_used fdset is_ssl
 );
@@ -220,6 +227,7 @@ sub set_metadata {
           || 2 * $self->max_bson_object_size );
 
     $self->_set_does_write_commands( $self->accepts_wire_version(2) );
+    $self->_set_supports_collation( $self->accepts_wire_version(5) );
 
     return;
 }
