@@ -17,7 +17,7 @@
 package MongoDB::_Server;
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 use MongoDB::_Types qw(
@@ -44,7 +44,6 @@ use namespace::clean -except => 'meta';
 has address => (
     is       => 'ro',
     isa      => HostAddress,
-    coerce   => HostAddress->coercion,
     required => 1,
 );
 
@@ -134,11 +133,12 @@ for my $s (qw/hosts passives arbiters/) {
         is      => 'lazy',
         isa     => HostAddressList,
         builder => "_build_$s",
-        coerce  => HostAddressList->coercion,
     );
 
     no strict 'refs';
-    *{"_build_$s"} = sub { $_[0]->is_master->{$s} || [] };
+    *{"_build_$s"} = sub {
+        [ map { lc $_ } ( @{ $_[0]->is_master->{$s} || [] } ) ];
+    };
 }
 
 
@@ -195,6 +195,21 @@ sub _build_tags {
     return $self->is_master->{tags} || {};
 }
 
+# last_write_date: for replica set and wire version 5+ (converted to
+# seconds)
+has last_write_date => (
+    is      => 'lazy',
+    isa     => Num,
+    builder => "_build_last_write_date",
+);
+
+sub _build_last_write_date {
+    my ($self) = @_;
+    return 0 unless exists $self->is_master->{lastWrite}{lastWriteDate};
+    # with dt_type undef, this should be floating point epoch seconds
+    return $self->is_master->{lastWrite}{lastWriteDate};
+}
+
 has is_available => (
     is      => 'lazy',
     isa     => Bool,
