@@ -17,19 +17,22 @@
 package MongoDB::_Topology;
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Moo;
 use MongoDB::BSON;
 use MongoDB::Error;
 use MongoDB::Op::_Command;
+use MongoDB::_Platform;
 use MongoDB::ReadPreference;
 use MongoDB::_Constants;
 use MongoDB::_Link;
 use MongoDB::_Types qw(
     BSONCodec
+    Document
     NonNegNum
     TopologyType
+    to_IxHash
 );
 use Types::Standard qw(
     Bool
@@ -83,6 +86,12 @@ has type => (
     isa => TopologyType,
 );
 
+has app_name => (
+    is      => 'ro',
+    default => '',
+    isa     => Str,
+);
+
 has replica_set_name => (
     is      => 'ro',
     default => '',
@@ -163,6 +172,13 @@ has max_set_version => (
     writer => '_set_max_set_version',
 );
 
+# generated only once per _Topology, for performance
+has handshake_document => (
+    is      => 'lazy',
+    isa     => Document,
+    builder => '_build_handshake_document',
+);
+
 # compatible wire protocol
 has is_compatible => (
     is => 'ro',
@@ -170,6 +186,12 @@ has is_compatible => (
     isa => Bool,
 );
 
+has wire_version_floor => (
+    is => 'ro',
+    writer => '_set_wire_version_floor',
+    default => 0,
+);
+
 has current_primary => (
     is => 'rwp',
     clearer => '_clear_current_primary',
@@ -208,13 +230,40 @@ has rtt_ewma_sec => (
 
 sub _build_number_of_seeds {
     my ($self) = @_;
-    return scalar @{ $self->uri->hostpairs };
+    return scalar @{ $self->uri->hostids };
+}
+
+sub _truncate_for_handshake {
+    my $str = shift;
+    return substr( $str, 0, 64 );
+}
+
+sub _build_handshake_document {
+    my ($self) = @_;
+    my $driver_version_without_leading_v = substr( $VERSION, 1 );
+
+    return to_IxHash(
+        [
+            ( length( $self->app_name ) ? ( application => { name => $self->app_name } ) : () ),
+            driver => to_IxHash(
+                [
+                    name    => "MongoDB Perl Driver",
+                    version => $driver_version_without_leading_v,
+                ]
+            ),
+            os => { type => _truncate_for_handshake(MongoDB::_Platform::os_type) },
+            platform => _truncate_for_handshake(MongoDB::_Platform::platform_details)
+        ]
+    );
 }
 
 sub BUILD {
     my ($self) = @_;
     my $type = $self->type;
-    my @addresses = @{ $self->uri->hostpairs };
+    my @addresses = @{ $self->uri->hostids };
+
+    # clone bson codec to disable dt_type
+    $self->{bson_codec} = $self->bson_codec->clone( dt_type => undef );
 
     if ( my $set_name = $self->replica_set_name ) {
         if ( $type eq 'Single' || $type eq 'ReplicaSetNoPrimary' ) {
@@ -250,7 +299,7 @@ sub check_address {
 
     my $link = $self->links->{$address};
     if ( $link && $link->is_connected ) {
-        $self->_update_topology_from_link($link);
+        $self->_update_topology_from_link( $link, with_handshake => 0 );
     }
     else {
         # initialize_link will call update_topology_from_link
@@ -271,9 +320,9 @@ sub get_readable_link {
 
     my $mode = $read_pref ? lc $read_pref->mode : 'primary';
     my $method =
-      ( $self->type eq "Single" || $self->type eq "Sharded" )
-      ? '_find_any_server'
-      : "_find_${mode}_server";
+        $self->type eq "Single"  ? '_find_available_server'
+      : $self->type eq "Sharded" ? '_find_readable_mongos_server'
+      :                            "_find_${mode}_server";
 
     if ($mode eq 'primary' && $self->current_primary) {
         my $link = $self->_get_server_link( $self->current_primary, $method );
@@ -314,7 +363,7 @@ sub get_writable_link {
 
     my $method =
       ( $self->type eq "Single" || $self->type eq "Sharded" )
-      ? '_find_any_server'
+      ? '_find_available_server'
       : "_find_primary_server";
 
 
@@ -451,21 +500,50 @@ sub _check_oldest_server {
     return;
 }
 
+my $max_int32 = 2147483647;
+
 sub _check_wire_versions {
     my ($self) = @_;
 
     my $compat = 1;
+    my $min_seen = $max_int32;
     for my $server ( grep { $_->is_available } $self->all_servers ) {
         my ( $server_min_wire_version, $server_max_wire_version ) =
           @{ $server->is_master }{qw/minWireVersion maxWireVersion/};
 
-        if (   ( $server_min_wire_version || 0 ) > $self->max_wire_version
-            || ( $server_max_wire_version || 0 ) < $self->min_wire_version )
-        {
-            $compat = 0;
-        }
+        $server_max_wire_version = 0 unless defined $server_max_wire_version; 
+        $server_min_wire_version = 0 unless defined $server_min_wire_version; 
+
+        $compat = 0
+          if $server_min_wire_version > $self->max_wire_version
+          || $server_max_wire_version < $self->min_wire_version;
+
+        $min_seen = $server_max_wire_version if $server_max_wire_version < $min_seen;
     }
     $self->_set_is_compatible($compat);
+    $self->_set_wire_version_floor($min_seen);
+
+    return;
+}
+
+sub _check_staleness_compatibility {
+    my ($self, $read_pref) = @_;
+
+    if ( $read_pref && $read_pref->max_staleness_ms > 0 ) {
+        if ( $self->wire_version_floor < 5 ) {
+            MongoDB::ProtocolError->throw(
+                "Incompatible wire protocol version. You tried to use max_staleness_ms with one or more servers that don't support it."
+            );
+        }
+
+        if (
+            ( $self->type eq "ReplicaSetWithPrimary" || $self->type eq "ReplicaSetNoPrimary" )
+            && $read_pref->max_staleness_ms < 2000 * $self->heartbeat_frequency_sec )
+        {
+            MongoDB::UsageError->throw(
+                "max_staleness_ms must be at least twice heartbeat_frequency_ms" );
+        }
+    }
 
     return;
 }
@@ -478,29 +556,89 @@ sub _dump {
 sub _eligible {
     my ( $self, $read_pref, @candidates ) = @_;
 
-    return @candidates
-      if $read_pref->has_empty_tag_sets;
+    # must filter on max staleness first, so that the remaining servers
+    # are checked against the list of tag_sets
+    if ( $read_pref->max_staleness_ms > 0 ) {
+        @candidates = $self->_filter_fresh_servers($read_pref, @candidates );
+        return unless @candidates;
+    };
 
     # given a tag set list, if a tag set matches at least one
     # candidate, then all candidates matching that tag set are eligible
-    for my $ts ( @{ $read_pref->tag_sets } ) {
-        my @eligible = grep { $_->matches_tag_set($ts) } @candidates;
-        return @eligible if @eligible;
+    if ( ! $read_pref->has_empty_tag_sets ) {
+        for my $ts ( @{ $read_pref->tag_sets } ) {
+            if ( my @ts_candidates = grep { $_->matches_tag_set($ts) } @candidates ) {
+                return @ts_candidates;
+            }
+        }
+        return;
     }
 
-    return;
+    return @candidates;
 }
 
-sub _find_any_server {
-    my ( $self, undef, @candidates ) = @_;
+sub _filter_fresh_servers {
+    my ($self, $read_pref, @candidates) = @_;
+
+    # all values should be floating point seconds
+    my $max_staleness_sec = $read_pref->max_staleness_ms / 1000;
+    my $heartbeat_frequency_sec = $self->heartbeat_frequency_sec;
+
+    if ( $self->type eq 'ReplicaSetWithPrimary' ) {
+        my ($primary) = $self->_primaries;
+
+        # all values should be floating point seconds
+        my $p_last_write_date = $primary->last_write_date;
+        my $p_last_update_time = $primary->last_update_time;
+
+        return map { $_->[0] }
+          grep { $_->[1] <= $max_staleness_sec }
+          map {
+            [
+                $_,
+                $p_last_write_date
+                  + ( $_->last_update_time - $p_last_update_time )
+                  - $_->last_write_date
+                  + $heartbeat_frequency_sec
+            ]
+          } @candidates;
+    }
+    else {
+        my ($smax) = map { $_->[0] }
+          sort { $b->[1] <=> $a->[1] }
+          map { [ $_, $_->last_write_date ] } $self->_secondaries;
+        my $smax_last_write_date = $smax->last_write_date;
+
+        return map { $_->[0] }
+          grep     { $_->[1] <= $max_staleness_sec }
+          map {
+            [ $_, $smax_last_write_date - $_->last_write_date + $heartbeat_frequency_sec ]
+          } @candidates;
+    }
+}
+
+# This works for reads and writes; for writes, $read_pref will be undef
+sub _find_available_server {
+    my ( $self, $read_pref, @candidates ) = @_;
+    $self->_check_staleness_compatibility($read_pref) if $read_pref;
     push @candidates, $self->all_servers unless @candidates;
     return $self->_get_server_in_latency_window(
         [ grep { $_->is_available } @candidates ] );
 }
 
+# This uses read preference to check for max staleness compatibility in
+# mongos, but otherwise read preference is ignored (mongos will pass it on)
+sub _find_readable_mongos_server {
+    my ( $self, $read_pref, @candidates ) = @_;
+    $self->_check_staleness_compatibility($read_pref);
+    push @candidates, $self->all_servers unless @candidates;
+    return $self->_get_server_in_latency_window(
+        [ grep { $_->is_available } @candidates ] );
+}
 
 sub _find_nearest_server {
     my ( $self, $read_pref, @candidates ) = @_;
+    $self->_check_staleness_compatibility($read_pref);
     push @candidates, ( $self->_primaries, $self->_secondaries ) unless @candidates;
     my @suitable = $self->_eligible( $read_pref, @candidates );
     return $self->_get_server_in_latency_window( \@suitable );
@@ -516,12 +654,14 @@ sub _find_primary_server {
 
 sub _find_primarypreferred_server {
     my ( $self, $read_pref, @candidates ) = @_;
+    $self->_check_staleness_compatibility($read_pref);
     return $self->_find_primary_server(@candidates)
       || $self->_find_secondary_server( $read_pref, @candidates );
 }
 
 sub _find_secondary_server {
     my ( $self, $read_pref, @candidates ) = @_;
+    $self->_check_staleness_compatibility($read_pref);
     push @candidates, $self->_secondaries unless @candidates;
     my @suitable = $self->_eligible( $read_pref, @candidates );
     return $self->_get_server_in_latency_window( \@suitable );
@@ -529,6 +669,7 @@ sub _find_secondary_server {
 
 sub _find_secondarypreferred_server {
     my ( $self, $read_pref, @candidates ) = @_;
+    $self->_check_staleness_compatibility($read_pref);
     return $self->_find_secondary_server( $read_pref, @candidates )
       || $self->_find_primary_server(@candidates);
 }
@@ -596,7 +737,7 @@ sub _initialize_link {
 
     # connection succeeded, so register link and get a server description
     $self->links->{$address} = $link;
-    $self->_update_topology_from_link($link);
+    $self->_update_topology_from_link( $link, with_handshake => 1 );
 
     # after update, server might or might not exist in the topology;
     # if not, return nothing
@@ -605,7 +746,7 @@ sub _initialize_link {
     # we have a link and the server is a valid member, so
     # try to authenticate; if authentication fails, all
     # servers are considered invalid and we throw an error
-    if ( first { $_ eq $server->type } qw/Standalone Mongos RSPrimary RSSecondary/ ) {
+    if ( $self->type eq 'Single' || first { $_ eq $server->type } qw/Standalone Mongos RSPrimary RSSecondary/ ) {
         try {
             $self->credential->authenticate($link, $self->bson_codec);
         }
@@ -722,14 +863,22 @@ sub _selection_timeout {
 
 my $PRIMARY = MongoDB::ReadPreference->new;
 
+sub _generate_ismaster_request {
+    my ($self, $should_perform_handshake) = @_;
+    return [
+        ismaster => 1,
+        ($should_perform_handshake ? (client => $self->handshake_document) : ()),
+    ];
+}
+
 sub _update_topology_from_link {
-    my ( $self, $link ) = @_;
+    my ( $self, $link, %opts ) = @_;
 
     my $start_time = time;
     my $is_master = eval {
         my $op = MongoDB::Op::_Command->_new(
             db_name         => 'admin',
-            query           => [ ismaster => 1 ],
+            query           => $self->_generate_ismaster_request( $opts{with_handshake} ),
             query_flags     => {},
             bson_codec      => $self->bson_codec,
             read_preference => $PRIMARY,
