@@ -19,7 +19,7 @@ package MongoDB::_Types;
 # MongoDB type definitions
 
 use version;
-our $VERSION = 'v1.3.4'; # TRIAL
+our $VERSION = 'v1.5.0'; # TRIAL
 
 use Type::Library
   -base,
@@ -35,6 +35,7 @@ use Type::Library
   Document
   ErrorStr
   HashLike
+  HeartbeatFreq
   HostAddress
   HostAddressList
   IndexModel
@@ -42,7 +43,6 @@ use Type::Library
   IxHash
   MongoDBCollection
   MongoDBDatabase
-  MongoDBQuery
   NonEmptyStr
   NonNegNum
   OID
@@ -98,15 +98,19 @@ declare ErrorStr, as Str, where { $_ }; # needs a true value
 
 declare HashLike, as Ref, where { reftype($_) eq 'HASH' };
 
+declare HeartbeatFreq, as Num,
+  where { defined($_) && $_ >= 500 },
+  message { "value must be at least 500" };
+
 # XXX loose address validation for now.  Host part should really be hostname or
 # IPv4/IPv6 literals
 declare HostAddress, as Str,
   where { $_ =~ /^[^:]+:[0-9]+$/ and lc($_) eq $_ }, message {
-    "Address '$_' not formatted as 'hostname:port'"
+    "Address '$_' either not lowercased or not formatted as 'hostname:port'"
   };
 
 declare HostAddressList, as ArrayRef [HostAddress], message {
-    "Address list <@$_> is not all hostname:port pairs"
+    "Address list <@$_> not all formatted as lowercased 'hostname:port' pairs"
 };
 
 class_type IxHash, { class => 'Tie::IxHash' };
@@ -117,8 +121,6 @@ class_type MongoDBCollection, { class => 'MongoDB::Collection' };
 
 class_type MongoDBDatabase, { class => 'MongoDB::Database' };
 
-class_type MongoDBQuery, { class => 'MongoDB::_Query' };
-
 declare NonEmptyStr, as Str, where { defined $_ && length $_ };
 
 declare NonNegNum, as Num,
@@ -184,12 +186,6 @@ coerce DBRefDB, from MongoDBDatabase, via { $_->name };
 
 coerce ErrorStr, from Str, via { $_ || "unspecified error" };
 
-coerce HostAddress, from Str, via { /:/ ? lc $_ : lc "$_:27017" };
-
-coerce HostAddressList, from ArrayRef, via {
-    [ map { /:/ ? lc $_ : lc "$_:27017" } @$_ ]
-};
-
 coerce ReadPrefMode, from Str, via { $_ = lc $_; s/_?preferred/Preferred/; $_ };
 
 coerce IxHash, from HashRef, via { Tie::IxHash->new(%$_) };
